%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  Calcul_Release_SF6
%%% Helps in calculation of a Lagrangian (spiral) route 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 11/09/2010 : gilles.rougier@univmed.fr & andrea.doglioli@univmed.fr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help Calcul_Release_SF6
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%
% initialisations

% directories of position data
dirin_buoy='../Bouee_NicolasMartin/';
dirin_vessel='../Suroit/';
%
%- area limits -% (in degres)
% Entrer par des menus fenetre
lon_min =  3.45;
lon_max =  3.60;
lat_min = 42.7;
lat_max = 42.8;
m_proj('mercator','lon',[lon_min lon_max],'lat',[lat_min lat_max]);

% Parametres Spirales
% nombre_de_creneaux,pasx,pasy
% 3,500,500
Nb_De_Creneaux = 6;
Pas_En_X = 500; %en m
Pas_En_Y = 500;
Distance_De_Passage_Au_Point_Suivant = 150; %en mtres

%% Vitesse fixee 3 noeuds
vitesse_bateau = 3*1856/3600;  %%% convertie en m/sec 

disp('----------------- Release SF6 -------------')
%% Point vise
j=input(' Numero du point vise (99 pour revenir a la bouee) ? ');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LECTURE DES POSITIONS BOUEES ET BATEAU
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% appel de la fonction de lecture de la trame bouee
% ordre = 0 derniere position
%[ tbouee_new,latitude_bouee_new,longitude_bouee_new ] = lecture_trame_fichier_bouee(dirin_buoy,0) ;
[ tbouee_new,latitude_bouee_new,longitude_bouee_new ] = lecture_trame_fichier_bouee_tethys(dirin_buoy,0) ;
% ordre = 1 avant derniere position
[ tbouee_old,latitude_bouee_old,longitude_bouee_old ] = lecture_trame_fichier_bouee_tethys(dirin_buoy,1) ;

% appel de la fonction de lecture de la trame bateau
%[ tbateau_new,latitude_bateau_new,longitude_bateau_new, vitesse_bateau_lu,cap_bateau_lu] = lecture_trame_fichier_bateau(dirin_vessel);
[ tbateau_new,latitude_bateau_new,longitude_bateau_new, vitesse_bateau_lu,cap_bateau_lu] = lecture_trame_fichier_bateau_tethys(dirin_vessel);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TEST QUALITE DES DONNEES BOUEE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

qualite=1;

% Test vitesse de courant raliste

rt=6371000;
dy=rt*(latitude_bouee_new - latitude_bouee_old)*pi/180;
dx=rt*cos(latitude_bouee_new*pi/180)*(longitude_bouee_new-longitude_bouee_old)*pi/180;
utest=dx/(tbouee_new-tbouee_old);
vtest=dy/(tbouee_new-tbouee_old);
moduletest= sqrt(utest^2+vtest^2);

if moduletest==0 
    qualite=0;
end

if moduletest>10  % (m/s), soit ~2 noeuds
    qualite=0;
end

if qualite==0
    latitude_bouee_new=latitude_bouee_old;
    longitude_bouee_new=longitude_bouee_old;
    tbouee_new=tbouee_old;
end

disp(' ')
disp(' TEST Qualite')
disp([' qualite = ',num2str(qualite)])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CALCUL DES COORDONNEES CARTESIENNES DE LA BOUEE ET DU BATEAU
% function [X Y]=lat_lon_2_XY(latitude,longitude,lat_origine,lon_origine)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Bouee
[xbouee_old ybouee_old] = m_ll2xy(longitude_bouee_old,latitude_bouee_old); %en km
[xbouee_new ybouee_new] = m_ll2xy(longitude_bouee_new,latitude_bouee_new);
% Bateau
[xbateau_new ybateau_new] = m_ll2xy(longitude_bateau_new,latitude_bateau_new);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CALCUL DES COMPOSANTES DE LA VITESSE DU COURANT
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% deduite de la derive de la bouee
% deplacement/temps 
[s,a12,a21] = m_idist(longitude_bouee_old,latitude_bouee_old,longitude_bouee_new,latitude_bouee_new);
%
% a12 azimuth en degre par rapport au nord clockwise
% pol2cart en entree theta en radian triginometrique (anticlockwise par
% rapport a l'est)
%
% conversion trigo vers azimuth
% a12        = 90-theta*180/pi;
% conversion azimuth vers trigo
theta=(90-a12)*pi/180;
[dx,dy]=pol2cart(theta,s);
u_courant=dx/(tbouee_new-tbouee_old); %en m/s
v_courant=dy/(tbouee_new-tbouee_old); %en m/s
vitesse_courant=sqrt(u_courant^2+v_courant^2);
direction_courant=a12;
distance_bouee=s;
disp(' ')
disp(' Caracteristiques du Courant mesure ')
disp(['  Module ',num2str(vitesse_courant),' ms ',' Direction ',num2str(direction_courant),' deg'])
disp(['  Distance entre les deux positions de bouees ',num2str(distance_bouee),'m'])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CALCUL DES COORDONNEES DE CHACUN DES POINTS DE LA SPIRALE
% function coord_spirale=calcule_spirale(nombre_de_creneaux,pasx,pasy,xbouee,ybouee) 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% coord_spirale_old=calcule_spirale(Nb_De_Creneaux,Pas_En_X,Pas_En_Y,0,0)/1000;
% coord_spirale_new=calcule_spirale(Nb_De_Creneaux,Pas_En_X,Pas_En_Y,0,0)/1000;%en km
coord_spirale_old=calcule_spirale_v2(Nb_De_Creneaux,Pas_En_X,Pas_En_Y)/1000;
coord_spirale_new=calcule_spirale_v2(Nb_De_Creneaux,Pas_En_X,Pas_En_Y)/1000;%en km


[xc,yc]   = m_ll2xy(longitude_bouee_old,latitude_bouee_old);
xx=coord_spirale_old(1,:);
yy=coord_spirale_old(2,:);
[lonspir_old,latspir_old] = conversion_spirale(xc,yc,lon_min,lat_min,xx,yy);
[xc,yc]   = m_ll2xy(longitude_bouee_new,latitude_bouee_new);
xx=coord_spirale_new(1,:);
yy=coord_spirale_new(2,:);
[lonspir_new,latspir_new] = conversion_spirale(xc,yc,lon_min,lat_min,xx,yy);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CALCUL DES CONSIGNES DE NAVIGATION A PARTIR DE LA POSITION
% ACTUELLE DU BATEAU ET DU COURANT DE SURFACE
% ESTIME A PARTIR DES 2 DERNIERES POSITIONS SUCCESSIVES DE LA BOUEE 
%function [direction_courant, vitesse_courant, x_vise, y_vise, distance, cap_a_suivre, vitesse_bateau, duree_a_suivre, consigne_u_bateau,consigne_v_bateau] 
% = calcule_consignes (x0,y0,xbouee_new, ybouee_new, tbouee_new,xbouee_old,ybouee_old, tbouee_old, xbateau_new,ybateau_new,vitesse_bateau)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if j==99
    [lon_vise,lat_vise,distance,cap_a_suivre,vitesse_bateau,duree_a_suivre,consigne_u_bateau,consigne_v_bateau] ...
    = calcul_consignes (longitude_bateau_new,latitude_bateau_new,longitude_bouee_new,latitude_bouee_new,...
    u_courant,v_courant,xbateau_new,ybateau_new,vitesse_bateau,qualite);
else
    [lon_vise,lat_vise,distance,cap_a_suivre,vitesse_bateau,duree_a_suivre,consigne_u_bateau,consigne_v_bateau] ...
    = calcul_consignes (longitude_bateau_new,latitude_bateau_new,lonspir_new(j),latspir_new(j),...
    u_courant,v_courant,xbateau_new,ybateau_new,vitesse_bateau,qualite);
end

disp([' cap_a_suivre calcule ',num2str(cap_a_suivre)])
if lon_vise == 9999
    disp(' ')
    break
end

%%%%%%%%%%%%
% FIGURES
%%%%%%%%%%%%
fig_carte=figure(1);
set(gcf,'position',[375 41 904 687]);
hold on;
Trace_Carte;

Trace_Spirale(longitude_bouee_old,latitude_bouee_old,lonspir_old,latspir_old,'old');

Trace_Spirale(longitude_bouee_new,latitude_bouee_new,lonspir_new,latspir_new,'new');

Trace_Bateau(longitude_bateau_new,latitude_bateau_new,lon_vise,lat_vise);

hold off;

fig_stat=figure(2);
set(gca,'visible','off');
set(gcf,'position',[9 602 352 147]);
hold on;
status0=(' NOUVELLES CONSIGNES DE NAVIGATION  ');
status1=(['DERIVE MESUREE = ' num2str(vitesse_courant,'%5.2f'),'[m/s] ',num2str(direction_courant,'%3.0f'),'[degre]']);
status2=(['POINT VISE          numero = ',num2str(j,'%5.0f')]);
status3=(['Latitude = ',num2str(lat_vise),' Longitude = ',num2str(lon_vise)]);
status4=([' Distance = ',num2str(distance,'%7.0f'),'[m]']);
status5=([' NOUVELLE CONSIGNE : CAP = ', num2str(cap_a_suivre,'%5.0f'),' a ',num2str(vitesse_bateau*3600/1856,'%5.1f'),'[noeuds]']);
status6=([' DUREE = ',num2str(duree_a_suivre,'%5.0f'),'[s]    ETA = ',datestr(datenum(now)+duree_a_suivre/86400)]);
status7=([' Vitesse du Bateau Actuelle  = ',num2str(vitesse_bateau_lu,'%5.2f'),'[noeuds] ']);

ft=10;
hndl_txt=uicontrol('style','text','unit','normalized','position',[0 .9 1 0.1],'string',[status1],...
        'fontweight','bold','fontsize',ft);
hndl_txt=uicontrol('style','text','unit','normalized','position',[0 .8 1 0.1],'string',[status2],...
    'fontweight','bold','fontsize',ft);
hndl_txt=uicontrol('style','text','unit','normalized','position',[0 .7 1 0.1],'string',[status3],...
    'fontweight','bold','fontsize',ft);
hndl_txt=uicontrol('style','text','unit','normalized','position',[0 .5 1 0.1],'string',[status4],...
    'fontweight','bold','fontsize',ft);
hndl_txt=uicontrol('style','text','unit','normalized','position',[0 .4 1 0.1],'string',[status5],...
    'fontweight','bold','fontsize',ft,'backgroundcolor','r');
hndl_txt=uicontrol('style','text','unit','normalized','position',[0 .3 1 0.1],'string',[status6],...
    'fontweight','bold','fontsize',ft);
hndl_txt=uicontrol('style','text','unit','normalized','position',[0 .2 1 0.1],'string',[status7],...
    'fontweight','bold','fontsize',ft);
hold off;
set(fig_stat,'visible','on');
set(fig_carte,'visible','on');

hold off;

