function [lon_vise,lat_vise,distance,cap_a_suivre,vitesse_bateau,duree_a_suivre,u_bateau,v_bateau]...
    = calcul_consignes (longitude_bateau_new,latitude_bateau_new,lonspir_ptvise,latspir_ptvise,...
    u_courant,v_courant,xbateau_new,ybateau_new,vitesse_bateau,qualite)

%
% Calcul des consignes de navigation 
% pour joindre le prochain point de la Spirale
%
% Principe de fonctionnement
%
% En entree
% calcul_consignes 
% (   x0,y0
%    ,xbouee_new, ybouee_new,tbouee_new
%    ,xbouee_old,ybouee_old, tbouee_old,
%    ,xbateau_new,ybateau_new,
%    ,vitesse_bateau,
%    qualite)
%
% En sortie
% vitesse du courant calcule (module et direction)
% coordonnes du point vise et distance
% cap du bateau pour arriver au point vise
%
% Calcul du temps necessaire pour que la bouee et le bateau se trouve sur
% le mme point - la vitesse du bateau etant connue
%
% Calcul du courant (u et v)= distance/temps

disp(' ')
disp(' Calcul Consignes ')
%
% on resoud le systeme d'equations
% o t est le temps recherch
% le module de la vitesse_bateau est fixe
%
% xbateau_new+u_bateau*t = x0+u_courant*t
% ybateau_new+v_bateau*t = y0+v_courant*t
% (u_bateau^2+v_bateau^2)= vitesse_bateau^2
%
% a*t^2+b*t+c=0
%

[s,a12,a21] = m_idist(longitude_bateau_new,latitude_bateau_new,lonspir_ptvise,latspir_ptvise);
theta=(90-a12)*pi/180;
[dx,dy]=pol2cart(theta,s); %m

a=u_courant^2+v_courant^2-vitesse_bateau^2;
b=2*dx*u_courant+2*dy*v_courant;
c=dx^2+dy^2;

delta=b^2-4*a*c;

if delta>=0
    
    solution1=(-b-sqrt(delta))/(2*a);
    solution2=(-b+sqrt(delta))/(2*a);
    duree_a_suivre=max(solution1,solution2);
        
    u_bateau=(dx/duree_a_suivre)+u_courant;
    v_bateau=(dy/duree_a_suivre)+v_courant;
    
    cap_a_suivre=uv_2_cap(u_bateau,v_bateau);    
    v_bateau_calcule=sqrt(u_bateau^2+v_bateau^2);
    distance=v_bateau_calcule*duree_a_suivre;
    
    [lon_vise,lat_vise]=m_fdist(longitude_bateau_new,latitude_bateau_new,cap_a_suivre,distance);
    
else
    disp('OSTROGOTH, YA PAS DE SOLUTION')
    lon_vise=9999;
    lat_vise=9999;
    distance=9999;
    cap_a_suivre=9999;
    duree_a_suivre=9999;
    u_bateau=9999;
    v_bateau=9999;
    return
end

