%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Script for draw a geographical map with 
%%% measured current vectors
%%%
%%% INPUT : coastline .mat file
%%%
%%% OUTPUT: m_map figure of ADCP current
%%%
%%% ALGORITHM: calcuate de projection and
%%%            plot the FSLE manifolds
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 19/09/2010 : andrea.doglioli@univmed.fr: update for compatibility with
%%%              the others tools
%%% 17/09/2010 : ziyuan.hu@univmed.fr
%%%              francesco.nencioli@univmed.fr
%%%              marion.kersale@univmed.fr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help map_ADCP
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%%
%- Data directory -%
dirin_ADCP='../ADCP_Tethys/'; % To be changed to relative path
fname='final_ADCP_Saved.mat';
%
%- Time interval -%
interval=[datenum(2010,9,17,20,0,0) now];%datenum(2010,9,8,5,0,0)];
%
%- Depth -%
depth=15 ;%[m] positive
%
%- Plot Options
myopt='b';
%
%- Legend Options
myscale=5;
legend_unit=0.2;
legend_lon=4.;
legend_lat=42.20;
%
%- Map boundaries -%
lonmin=3;
lonmax=4.3;
latmin=42;
latmax=43.2;
%
%- Geographic projection for m_map -%
projection = 'mercator';
%
%- User coast in dirin -%
UserCoast='GOL.mat'; % in "sub_functions" directory
%
%- Plot the figure
figure(1); hold on; 
m_proj('mercator','lon',[lonmin lonmax],'lat',[latmin latmax])
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
plot_ADCP(dirin_ADCP,fname,interval,depth,myopt,myscale,legend_unit,legend_lon,legend_lat);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%- Figure title -%
title(['LATEX 2010 map-ADCP'])
%
%- NW Mediterranean High Resolution Isobaths -%
plot_BATHY('../BATHYMETRY_NWMED/',[200 500]);
%
%- User's High Resolution Coastline -%
m_usercoast(UserCoast,'patch',[.7 .7 .7],'edgecolor','k');
%m_coast('patch',[.7 .7 .7],'edgecolor','k');
%
%- Geographical Axis -%
m_grid('box','fancy','tickdir','in');
xlabel('Longtitude');
ylabel('Latitude');
%
%- Figure Printing -%
print(1,'./figures/map_ADCP.png','-dpng','-r200');
%
disp(' ');
disp('----- END ---')
