%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Script for draw a geographical map with ARGOS buoys trajecotries
%%%
%%% INPUT : coastline .mat file
%%%
%%% OUTPUT: m_map figure of FSLE manifolds and buoys trajectories
%%%
%%% ALGORITHM: calcuate de projection,
%%%            plot the trajectories and
%%%            print the figure
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 18/09/2010 : andrea.doglioli@univmed.fr : cycle on buoys_id added
%%% 17/09/2010 : francesco.nencioli@univmed.fr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help map_ARGOS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%%
%- Data directory -%
dirin_ARGOS='..\Bouee_NicolasMartin\';
%
%- Buoy identifiers' list -%
%%% buoys taken at 15/09 and redeployed th 18/9 dureing FSLE exp
buoylist=[48863 48903 48920 48939 48940]; 
%%% buoy from La Seyne
% buoylist=[48893 48942 93263];
%
%- Time interval of the trajectories -%
interval=[datenum(2010,9,20,0,0,0) now];%datenum(2010,9,20,6,0,0)];
interval1=[datenum(2010,9,21,10,0,0) now];
interval2=[datenum(2010,9,21,9,0,0) now];
interval3=[datenum(2010,9,21,10,0,0) now];
%
%- Map boundaries -%
lonmin=3;
lonmax=4.3;
latmin=42;
latmax=43.2;
%
%- Geographic projection for m_map -%
projection = 'mercator';
%
%- User coast in dirin -%
UserCoast='GOL.mat'; % in "sub_functions" directory
%
%- Plot the figure -%
figure(1); hold on; 
m_proj('mercator','lon',[lonmin lonmax],'lat',[latmin latmax])
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
% Loop plotting trajectories with same options
for buoy_id=buoylist
    plot_ARGOS(dirin_ARGOS,buoy_id,'ro',interval);
end
%%
% Single trajectories
%% Buoys launched during second FSLE experiment
plot_ARGOS(dirin_ARGOS,48893,'bo-',interval1);
plot_ARGOS(dirin_ARGOS,48942,'bo-',interval2);
plot_ARGOS(dirin_ARGOS,93263,'bo-',interval3);

%% Buoys lauchend off LaSeyne
% plot_Argos_buoys_id(dirin_ARGOS,48943,'ko',interval);
% plot_Argos_buoys_id(dirin_ARGOS,48944,'go',interval);
% plot_Argos_buoys_id(dirin_ARGOS,48945,'yo',interval);
% plot_Argos_buoys_id(dirin_ARGOS,48946,'ro',interval);

%% CARIOCA buoy
%plot_Argos_buoys_id(dirin_ARGOS,26128,'ko-',interval);

%% IRIDIUM buoy
%plot_Argos_buoys_id(dirin_ARGOS,300034012011820,'ro-',interval);

%% Buoys lauchend at last round of spiral
% plot_Argos_buoys_id(dirin_ARGOS,83631,'r*-',interval);
% plot_Argos_buoys_id(dirin_ARGOS,93265,'b*-',interval);
% plot_Argos_buoys_id(dirin_ARGOS,47833,'k*-',interval);
% plot_Argos_buoys_id(dirin_ARGOS,47835,'g*-',interval);

%% Bouee recuperes le 15 Sept
% plot_Argos_buoys_id(dirin_ARGOS,48863,'y*-',interval);
% plot_Argos_buoys_id(dirin_ARGOS,48903,'c*-',interval);
% plot_Argos_buoys_id(dirin_ARGOS,48920,'m*-',interval);
% plot_Argos_buoys_id(dirin_ARGOS,48939,'r*:',interval);
% plot_Argos_buoys_id(dirin_ARGOS,48940,'b*:',interval);

%% SURPLUS BUOYS
% plot_Argos_buoys_id(dirin_ARGOS,29457,'k*:',interval);
% plot_Argos_buoys_id(dirin_ARGOS,29491,'g*:',interval);
% plot_Argos_buoys_id(dirin_ARGOS,30448,'k+-',interval);
% plot_Argos_buoys_id(dirin_ARGOS,30394,'k+:',interval);
% plot_Argos_buoys_id(dirin_ARGOS,30471,'k*:',interval);

%% Tethys when encountered a buoy
%m_plot(3.555,42.751,'bo')
%m_text(3.555,42.751,' TETHYS 11-Sept-2010 16:40GMT')%,'BackgroundColor',[.9 .9 .9])
% m_plot(degmin_to_decideg(3,54.463),degmin_to_decideg(42,41.407),'bo')
% m_text(degmin_to_decideg(3,54.463),degmin_to_decideg(42,41.407),' TETHYS 20-Sept-2010 6:14GMT')%,'BackgroundColor',[.9 .9 .9])

%% buoy #48945 forecated position
% m_plot(3.9116,42.6885,'r*')
% m_text(3.9116,42.6885,' buoy #48945 forecasted position for 5:00GMT')%,'BackgroundColor',[.9 .9 .9])

%% Glider Phyteas last position
% lon=degmin_to_decideg(4,2.836)
% lat=degmin_to_decideg(42,44.169)
% m_text(lon,lat,'  Phyteas 18/09 8:42 ','BackgroundColor','y','HorizontalAlignment','Right')
% m_plot(lon,lat,'k*')
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%- Figure title -%
title(['LATEX 2010 map-ARGOS'])
%
%- NW Mediterranean High Resolution Isobaths -%
plot_BATHY('../BATHYMETRY_NWMED/',[200 500]);
%
%- User's High Resolution Coastline -%
m_usercoast(UserCoast,'patch',[.7 .7 .7],'edgecolor','k');
%m_coast('patch',[.7 .7 .7],'edgecolor','k');
%
%- Geographical Axis -%
m_grid('box','fancy','tickdir','in');
xlabel('Longtitude');
ylabel('Latitude');
%
%- Figure Printing -%
print(1,'./figures/map_ARGOS.png','-dpng','-r200');
%
disp(' ');
disp('----- END ---')
