%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%    LATEX track plotter    %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This  script  plots  the boat and buoy tracks in 
% lat/lon  coordinate   system    togheter    with
% buoy  track in the lagrangian  reference  system 
% of the buoy.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 05/09/01 AD: second version for LATEX2010
%              some bugs corrected
% 06/07/07 AD: first version LATEX00 with commented 
%              lines for sensivity tests
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% input : save_spir_1162007_sansNaN.asc
%         concat_radiateur_sansNaN.asc
%
% output: one .eps file
%       3 color codes for vessel track
%       ccode=1 > blue
%       ccode=2 > blue->red increasing with time
%       ccode=3 > blue->red increasing with time 
%                 interval between vessel positions
%
% remarks: M_MAP package is required
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%
help reconstitution
ccode=1%input(' color code ? [1(default) 2 3] ');
if isempty(ccode)==1
 ccode=1;
end
%
%%% DATA LOADING
dir_bouee='Z:\LATEX\Iridium\ScanEtrack\trame\'
[ timeb,latb,lonb ] = lecture_trame_fichier_bouee_tous(dir_bouee,0);

file_navire='Z:\LATEX\Iridium\ScanEtrack\pos_bateau.txt'
[ Time_Bateau,latv,lonv,vitesse_bateau,cap_bateau ] = lecture_trame_fichier_bateau_tous(file_navire);

save memo timeb latb lonb Time_Bateau latv lonv vitesse_bateau cap_bateau
load memo
%
%%% COMPUTATION OF VESSEL LAGRANGIAN POSITIONS
[trash,itmax]=size(lonv);
%new array repeting same postion of buoy
DT=(timeb(end)-timeb(1))/(length(lonv)-1);
newtimeb=timeb(1):DT:timeb(end);
newlonb=interp1(timeb,lonb,newtimeb,'linear');
newlatb=interp1(timeb,latb,newtimeb,'linear');

%distance calculation betweeb vessel and buoy
[s,a12,a21] = m_idist(newlonb,newlatb,lonv,latv);
theta=(90-a12)*pi/180;
[distx,disty]=pol2cart(theta,s);%[m]
distx=distx./1000; %[km]
disty=disty./1000; %[km]

%theorical spiral
Nb_De_Creneaux = 5;
Pas_En_X = 500; %en m
Pas_En_Y = 500;
Distance_De_Passage_Au_Point_Suivant = 150; %en mtres

coord_spirale_old=calcule_spirale(Nb_De_Creneaux,Pas_En_X,Pas_En_Y,0,0)/1000;
xx=coord_spirale_old(1,:);
yy=coord_spirale_old(2,:);

%%% PLOTTING
%%% M_MAP SETUP FOR STUDY AREA
m_proj('mercator','lon',[3.46 3.53],'lat',[42.665 42.715])
%m_gshhs_h('save','GoL'); 
%%% uncomment the line above the first time you run the script
%%% it creates GoL.mat file. When it is uncomment the script
%%% is very slow (more in M_MAP guide)
%
figure(1);
%
subplot(1,2,1);hold on;
%
title('vessel (blue) and buoy (red) tracks')
m_usercoast('GoL','patch',[.8 .8 .8])
m_line(lonb,latb,'marker','+','color','r');
m_line(lonv,latv,'color','b');
m_grid;
xlabel('longitude');
ylabel('latitude');
%
subplot(1,2,2);hold on;
%
title('vessel track in lagrangian reference')
if ccode==1
 plot(distx,disty,'-+');
elseif ccode==2
 for it=2:itmax
  red=(it/itmax);
  line(distx(it-1:it),disty(it-1:it),'marker','+','color',[red 0 1-red]);
 end
elseif ccode==3
 for it=1:itmax-1
  deltat(it)=time(it+1)-time(it);
 end
 maxdt=max(deltat);
 for it=itmax-1:-1:1
  red=deltat(it)/maxdt;
  line(distx(it:it+1),disty(it:it+1),'marker','+','color',[red 0 1-red]);
 end
end%if ccode
plot(xx,yy,'r')

axis square
xlabel('distance x [km]');
ylabel('distance y [km]');
text(-.15,-.15,'*','FontSize',30)
grid
box on;
%
%%% PRINTING
orient landscape
%saveas(iplot,['tmp',num2str(iplot),'.eps'],'epsc2');
saveas(1,['tmp.eps'],'epsc2');
%
%
disp(' ')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%