%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%    LATEX track plotter    %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This  script  plots  the sampling points of SF6 in
% the lagrangian reference frame of the Iridium buoy.
%
% ALGHORITM: read the position of the sampling point 
%            and the corresponding concentration of SF6
%            read the the position of the Iridium buoy
%            calculate the distance beetween the point 
%            and the Iridium
%
% INPUT: sf6_mapping_vessel_coord_nb*_VStethys.txt
%
% OUTPUT: plot of dots of concentration
%         plot of dots of interpolated concentration
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%% load the file with the positions for the second mapping

load ..\SF6\sf6_mapping_vessel_coord_nb3_VStethys.txt
%% convert date to number of days
timeSF6=datenum(sf6_mapping_vessel_coord_nb3_VStethys(:,3), ...
    sf6_mapping_vessel_coord_nb3_VStethys(:,2), ...
    sf6_mapping_vessel_coord_nb3_VStethys(:,1), ...
    sf6_mapping_vessel_coord_nb3_VStethys(:,4), ...
    sf6_mapping_vessel_coord_nb3_VStethys(:,5),0);
%% longitude and latitude of the sampled point
lonSF6=sf6_mapping_vessel_coord_nb3_VStethys(:,6);
latSF6=sf6_mapping_vessel_coord_nb3_VStethys(:,7);
%% SF6 concentration converted in % with respect to the maximum
concSF6=sf6_mapping_vessel_coord_nb3_VStethys(:,8);
concSF6=concSF6/max(concSF6)*100;
%% longitude and latitude of the buoy at the time the point was sampled
lonb=sf6_mapping_vessel_coord_nb3_VStethys(:,9);
latb=sf6_mapping_vessel_coord_nb3_VStethys(:,10);

%% distance calculation between sampling points and buoy
[s,a12,a21] = m_idist(lonb,latb,lonSF6,latSF6);
theta=(90-a12)*pi/180;
[distx,disty]=pol2cart(theta,s);%[m]
distx=distx./1000; %[km]
disty=disty./1000; %[km]

%%% PLOTTING
%
figure(1);hold on
%
title('Sampling points in the lagrangian reference (Conc. %) - Second SF6 mapping')
ylabel('Distance (km)')
xlabel('Distance (km)')
% plot a circle at (lonSF6,latSF6) with a color depending to concSF6
scale=7;
% colormap scales with the percentage with respect to the maximum value
% recorded during the current mapping
couleur=colormap;
n=length(concSF6);

% n=length(concSF6)-20;
% concSF6=concSF6(1:n);
% distx=distx(1:n);
% disty=disty(1:n);

mc=min(concSF6);
mac=max(concSF6);
% index for colormap: assign a color to each position depending on SF6 %
% 1+... is to have tp11c=1 for minimum values
tp11c=1+fix((concSF6-mc)*length(couleur)/(mac-mc));
% concentration smaller than minimum is still displayed as minimum
for i=1:n
    if(concSF6(i)<mc)
        tp11c(i)=1;
    end
    % set index color for maximum value to highest color
    % (couleur is 64x3 matrix)
    if(concSF6(i)>=mac)
        tp11c(i)=63;
    end
end

for i=1:n
    plot(distx(i),disty(i),'o','MarkerEdgeColor',couleur(tp11c(i),:),...
        'MarkerFaceColor',couleur(tp11c(i),:),'markersize',5);  
end 
caxis([0 mac])
colorbar
axis equal

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% gridding of the reconsituted point
[distxi,distyi]=meshgrid(distx,disty);
[conci]=griddata(distx,disty,concSF6,distxi,distyi,'v4');

figure(2);hold on;
pcolor(distxi,distyi,conci)
shading interp
colormap gray
mymap=colormap
colormap(1-mymap)
whos

plot(distx,disty,'k.')

caxis([0 100])
colorbar
axis equal

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
