function [totdist,xx,yy]=SpiralCalculator(nombre_de_creneaux,pasx,pasy)
%function coord_spirale=calcule_spirale_v2(nombre_de_creneaux,pasx,pasy)
% Computes a spiral with a number of corners defined by nombre_de_crenaux,
% and a longitudinal and latitudinal spacing defined by pasx and pasy respectively;
%
% There are a number of user defined switches that can be set to change
% the sense and type of rotation of the spiral.
%
% Francesco Nencioli 05-09-2010
%================================================================

%---------------------------
% User defined parameters: %
%---------------------------
% 1) Center of the spiral
acoord(1)=0;
bcoord(1)=0;
% 2) direction of the first step:
% the first step from the origin can be set to be 
% along y ('y') or along x ('x')
first_step='y';
% 3) sense of direction of the first 2 steps:
% - switch1 determines if the first step is towards positive (1) or negative (-1) direction
% - switch2 determines if the second step is towards positive (1) or negative (-1) direction
% (The rest of the spiral is computed iteratively)
switch1=+1;
switch2=+1;
%================================================================

% disp(' ')
% disp(' Calcul Spirale ')

if first_step=='x'
	pasa=pasx;
	pasb=pasy;
elseif first_step=='y'
	pasa=pasy;
	pasb=pasx;
else
	error('First_step can only be ''x'' or ''y'' ')
end

if abs(switch1)~=1 || abs(switch2)~=1
	error('switch1 or switch2 can only be +1 or -1')
end

% Start to iterativelly compute the spiral vertices.
% For each loop there are four points that are computed 
% until the number of loops reach the maximum defined by nombre_de_creneaux
for i=1:nombre_de_creneaux
	% compute position of first corner of the loop
	acoord((4*i)+1-3)=acoord(((4*i)+1-3)-1)+(switch1*pasa*(i*2-1));
	bcoord((4*i)+1-3)=bcoord(((4*i)+1-3)-1);
	switch1=-switch1;
	% compute position of second corner of the loop
	acoord((4*i)+1-2)=acoord((4*i)+1-3);
	bcoord((4*i)+1-2)=bcoord((4*i)+1-3)+(switch2*pasb*(i*2-1));
	switch2=-switch2;
	% compute position of third corner of the loop
	acoord((4*i)+1-1)=acoord((4*i)+1-2)+(switch1*pasa*(i*2));
	bcoord((4*i)+1-1)=bcoord((4*i)+1-2);
	switch1=-switch1;
	% compute position of fourth corner of the loop
	acoord((4*i)+1)=acoord((4*i)+1-1);
	bcoord((4*i)+1)=bcoord((4*i)+1-1)+(switch2*pasb*(i*2));
	switch2=-switch2;
end
% acoord and bcoord are saved as xcoord or ycoord depending on the values of first_step
if first_step=='x'
	xx=acoord;
	yy=bcoord;
elseif first_step=='y'
	xx=bcoord;
	yy=acoord;
end
% compute tot dist
i=1:nombre_de_creneaux*2;
totdist=sum((pasa+pasb)*i);
