function [lon_id,lat_id,next_lon,next_lat]=buoy_update(chosen_id,dirin,next_d,next_h,next_m,time_last)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%  buoy_update.m
%%  this subfunction computes the future positon of the buoys at time
%%  defined by next_d next_h and next_m;
%%  the velocity and direction of the buoy us estimated using the first and
%%  last point of the trajectory. Only the points after time_last are used
%%  in the computation;
%%
%%  Francesco Nencioli & Marion Kersale - 14/09/2010
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% load full list of files with buoy position
[time_id,lat,lon,drifter_id]=load_Argos_buoys(dirin);

% lat and lon vectors of the buoy defined by chosen_id
lon_id=lon(find(drifter_id==chosen_id));
lat_id=lat(find(drifter_id==chosen_id));
% time info of the buoy
time_id=time_id(find(drifter_id==chosen_id));

% keep only info more recent than time_last
lon_id=lon_id(time_id>=time_last);
lat_id=lat_id(time_id>=time_last);
time_id=time_id(time_id>=time_last);

% compute velocity from point to point (not output!!!)
ds=m_lldist(lon_id,lat_id);
dt=diff(time_id);
vel=(ds*100000)./(dt*24*60*60);
mean_v=mean(vel);
% compute average velocity using first and last point of hte trajectory
dS=m_lldist([lon_id(1) lon_id(end)],[lat_id(1),lat_id(end)]);
dT=time_id(end)-time_id(1);
Vel=dS./dT;
Vel_cm_sec=(dS*100000)./(dT*24*60*60);
% compute bouy direction
dx=m_lldist([lon_id(1) lon_id(end)],[lat(1) lat(1)]);
dy=m_lldist([lon_id(1) lon_id(1)],[lat_id(1) lat_id(end)]);
angle=atan(dy/dx);
if lon_id(1)>lon_id(end) & lat_id(1)<lat_id(end)
	angle=pi-angle;
elseif lon_id(1)>lon_id(end) & lat_id(1)>lat_id(end)
	angle=pi+angle;
elseif lon_id(1)<lon_id(end) & lat_id(1)>lat_id(end)
	angle=2*pi-angle;
end
% converson from date to number of days of the time at which the new
% position will be estimated
% IMPORTANT: Since we're using it for latex10 year and month are fixed to 2010 and
% 9!!!!!!!
time_next=datenum(2010,9,next_d,next_h,next_m,0);
% compute future distance (km) travelled
dist=Vel*(time_next-time_id(end));
% decompose distance in x and y dir
dY=dist*sin(angle);
dX=dist*cos(angle);
% first convert km to deg latitude (constant with longitude)
km2lat=m_lldist([lon_id(1) lon_id(1)],[lat_id(1) lat_id(1)+1]);
dlat=dY/km2lat;
next_lat=lat_id(end)+dlat;
% then convert km tolongitude at the updated latitude (km2lon varies with
% latitude)
km2lon=m_lldist([lon_id(end) lon_id(end)+1],[next_lat next_lat]);
dlon=dX/km2lon;
next_lon=lon_id(end)+dlon;
