%this function draw a spiral starting from a chosen center
%
%inputs
% pasX [km].....distance between 2 concentric circles
% ext_xlon[km]......zonal extention of the larger circle
% maxdist [nm]..maximal lenght of the boat trajectory
% ratio.........between zonal and meridional extention
% near [degree].minimal distance between chosen center and calculated spiral last point
%
%outputs
% totdistanceKM [km].maximal lenght of the boat trajectory
% (xx,yy)............coord of spiral corners [km]
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 28/05/2010 A.M.Doglioli & A.A.Petrenko
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [totdistanceKM,xx,yy]=funct_sampling(pasX,ext_xlon,maxdist,ratio,near)

  pasY     = pasX     * ratio;
  ext_ylat = ext_xlon * ratio;

  %spiral center on (0,0)
  xx(1) = -ext_xlon/2; %km
  yy(1) = +ext_ylat/2; 
  xx(2) = +ext_xlon/2; 
  yy(2) = yy(1);
  xx(3) = xx(2);
  yy(3) = -ext_ylat/2;

  theta(3) = 90; %angle of spiral rotation
  
  totdistanceKM = ext_xlon + ext_ylat;
  
  dx_min = 1; %[km] to maximize
  dy_min = 1;
  
  lastxx = xx(1);
  lastyy = yy(1);
  
  i = 4;

  totdistanceKM = 0.;

  while totdistanceKM <= maxdist*1.852 && (...
       abs(dx_min-lastxx)>near || abs(dy_min-lastyy)>near ||...
       abs(lastxx-dx_min)>near || abs(lastyy-dy_min)>near )

   ii=i-1;
   
   theta(i) = fix(theta(i-1)+90);
   
   if rem(i, 2) ~= 0
     xx(i)=xx(i-1);
     yy(i)=yy(i-1)-(ext_ylat-(ii-1)/2*pasY)*sin(theta(i)*pi/180);
     distance=max(yy(i-1),yy(i)) - min(yy(i-1),yy(i));
   else
     xx(i)=xx(i-1)+(ext_xlon-(ii-1)/2*pasX)*cos(theta(i)*pi/180);   
     yy(i)=yy(i-1);
     distance=max(xx(i-1),xx(i)) - min(xx(i-1),xx(i));%[km]
   end

  lastxx=xx(i);
  lastyy=yy(i);

  totdistanceKM = totdistanceKM + distance;

  i = i + 1;

end %while

