%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% function [lon,lat,temp,u,v,amp,angle,nE,nC,gyro,info_transect]=load_ADCP(dirin,fname,tr_file)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% script for loading data of the FSLE data
%%%
%%% INPUT : FSLE_yyyymmdd.mat
%%%
%%% OUTPUT: lon and lat of the points with FSLE > .2 [days^-1]<-CHECK!!!!!!
%%% 
%%%
%%% ALGORITHM: load MAT file containing the position of the FSLE > 
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 17/09/2010 : ziyuan.hu@univmed.fr
%%%              francesco.nencioli@univmed.fr
%%%              marion.kersale@univmed.fr
%%% Credits :    ZiYuan HU 17/02/2009
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [lon,lat,temp,u,v,amp,angle,nE,nC,gyro,info_transect]=load_ADCP(dirin,fname,tr_file)

% Set the treshold to label bad data
seuil=999;

load([dirin,fname]);
%  whos
[a,b]=size(ensemble);% nE x 15

 if a~=nEnsembles
     disp('Errors in nEnsembles. Please verify')
%       break
 else
     disp(['Total nEnsembles = ',num2str(a)]);
 end


gyro=sensors(:,1);
lon=ensemble(:,14); % nE x 1
lat=ensemble(:,13);
temp=ensemble(:,11);
u=eastCurrentComponent'; % 60 x nE
v=northCurrentComponent';
u=u/100; % pour avoir en m/s
v=v/100;
[amp,angle]=umod(u,v);
%  max(max(amp))
nE=nEnsembles;
nC=nCells;
for i=1:nC
    for j=1:nE
        if amp(i,j)<=0 | amp(i,j)>=seuil
            u(i,j)=NaN;
            v(i,j)=NaN;
            amp(i,j)=NaN;
        end
    end
end

% max(max(amp))

% Load transect limit file
if exist([dirin,tr_file])
	info_transect=load([dirin,tr_file]);
else
	info_transect=0;
end


return



