function [a b c]=set_vectors(Lon,Lat,u,v)
%-----------------------------------------------------------------------------------
% Purpose:
% 1) Select the point of velocity reversal
% 2) Choose the vectors around that point to be used in the COE
%
% Hu & Nencioli Sept 2010
%-----------------------------------------------------------------------------------
% Quiver plot to choose the point of velocity reversal
m_proj('mercator','lon',[Lon(1)-0.25 Lon(end)+0.25],'lat',[Lat(end)-0.1 Lat(1)+0.1])
figure(1)
m_grid('box','fancy')
hold on
m_quiver(Lon,Lat,u,v,1)
m_gshhs_i

disp('%------------------------------------------')

button='n'; % Switch to end the process
while button=='n'

	disp('Please click the point close to the velocity reversal (Left click)')
	[x1,y1,dummy] = ginput(1);
	
	% Find the index of the point closest to the selected one
	if dummy==1
		[lon1,lat1]=m_xy2ll(x1,y1);
		d=inf;
		a=0;
		for i=1:length(Lon)
			dist=m_lldist([lon1;Lon(i)],[lat1;Lat(i)]);
			if dist<d
				d=dist;
				a=i;
			end
		end
		% Zoom quiver plot around the selected point
		step=20;
		m_proj('mercator','lon',[Lon(max(a-step,1))-0.01 Lon(min(a+step,size(Lon,1)))+0.01], ...
			'lat',[Lat(max(a-step,1))-0.02 Lat(min(a+step,size(Lat,1)))+0.02])
		figure;
		m_grid
		hold on
		m_quiver(Lon(max(a-step,1):min(a+step,size(Lon,1))), ...
			Lat(max(a-step,1):min(a+step,size(Lat,1))), ...
			u(max(a-step,1):min(a+step,size(u,1))), ...
			v(max(a-step,1):min(a+step,size(v,1))), ...
			'linewidth',1)
		hold on
		m_plot(Lon(a),Lat(a),'rx','linewidth',2,'markersize',10)

		% Confirm the point selected
		button=input(['Velocity reversal point n1=',num2str(a),'; Confirm: [y/n] '],'s');
		
		% If the selection is not confirmed then the plot is refreshed 
		% and a new selection is promped
		if button=='n'
			close all
			figure;
			m_grid
			hold on
			m_quiver(Lon(a-step:a+step),Lat(a-step:a+step),u(a-step:a+step),v(a-step:a+step),'linewidth',1)

			disp('Chose another point')

		else
			% If the selection is confirmed then the process moves to the vector selection 
			close all
		end
	end
end

% New plot to select the vectors that will be used in the COE estimate
m_proj('mercator','lon',[Lon(1)-0.25 Lon(end)+0.25],'lat',[Lat(end)-0.1 Lat(1)+0.1])
figure(1)
m_grid('box','fancy')
m_gshhs_i
hold on

disp('%------------------------------------------')

uigood='n'; % Switch to stop the process
while uigood=='n'
	m_quiver(Lon,Lat,u,v,0,'color','b')
	m_plot(Lon(a),Lat(a),'r*')

	% user input
	dd=input('Please enter the number of vectors around the red * to be used for the COE: ');

	min_i=max(a-dd,1);
	max_i=min(a+dd,size(Lon,1));
	m_quiver(Lon(min_i:max_i),Lat(min_i:max_i),u(min_i:max_i),v(min_i:max_i),0,'color','r')

	% Confirm the selection
	uigood=input('Do you want to keep the red vectors for the COE? [y,n]','s');
end
% set the variable to output
b=min_i;
c=max_i;
close all
